@@ -12,6 +12,7 @@ pub struct StartCommand {
     pub keyring: Vec<KeyRingEntry>,
     pub dns_config: Resolver,
     pub proxy: Option<SocketAddr>,
+    pub user_agent: Option<String>,
     pub options: HashMap<String, String>,
     pub module: Module,
     pub arg: serde_json::Value,
@@ -23,6 +24,7 @@ impl StartCommand {
                keyring: Vec<KeyRingEntry>,
                dns_config: Resolver,
                proxy: Option<SocketAddr>,
+               user_agent: Option<String>,
                options: HashMap<String, String>,
                module: Module,
                arg: serde_json::Value,
@@ -33,6 +35,7 @@ impl StartCommand {
             keyring,
             dns_config,
             proxy,
+            user_agent,
             options,
             module,
             arg,
