@@ -41,6 +41,7 @@ pub enum Command {
     Mod,
     Noscope,
     Pkg,
+    Rescope,
     Run,
     Scope,
     Set,
@@ -56,6 +57,7 @@ pub enum Command {
     Quit,
 
     Interrupt,
+    Exec(String),
 }
 
 impl Command {
@@ -73,6 +75,7 @@ impl Command {
             Command::Mod => "mod",
             Command::Noscope => "noscope",
             Command::Pkg => "pkg",
+            Command::Rescope => "rescope",
             Command::Run => "run",
             Command::Scope => "scope",
             Command::Set => "set",
@@ -85,6 +88,7 @@ impl Command {
             Command::Workspace => "workspace",
             Command::Cal => "cal",
             Command::Interrupt => unreachable!(),
+            Command::Exec(_) => unreachable!(),
         }
     }
 
@@ -102,6 +106,7 @@ impl Command {
                 Command::Keyring.as_str(),
                 Command::Noscope.as_str(),
                 Command::Pkg.as_str(),
+                Command::Rescope.as_str(),
                 Command::Run.as_str(),
                 Command::Scope.as_str(),
                 Command::Set.as_str(),
@@ -135,15 +140,16 @@ impl FromStr for Command {
             "keyring" => Ok(Command::Keyring),
             "mod" => Ok(Command::Mod),
             "noscope" => Ok(Command::Noscope),
-            "pkg"  => Ok(Command::Pkg),
-            "run"  => Ok(Command::Run),
-            "scope"  => Ok(Command::Scope),
-            "set"  => Ok(Command::Set),
+            "pkg" => Ok(Command::Pkg),
+            "rescope" => Ok(Command::Rescope),
+            "run" => Ok(Command::Run),
+            "scope" => Ok(Command::Scope),
+            "set" => Ok(Command::Set),
             "select" => Ok(Command::Select),
             "stats" => Ok(Command::Stats),
-            "target"  => Ok(Command::Target),
-            "use"  => Ok(Command::Use),
-            "quickstart"  => Ok(Command::Quickstart),
+            "target" => Ok(Command::Target),
+            "use" => Ok(Command::Use),
+            "quickstart" => Ok(Command::Quickstart),
             "quit" => Ok(Command::Quit),
             "workspace" => Ok(Command::Workspace),
             "cal" => Ok(Command::Cal),
@@ -273,7 +279,7 @@ impl<'a> Shell<'a> {
 
     #[inline(always)]
     pub fn config(&self) -> &Config {
-        &self.config
+        self.config
     }
 
     #[inline(always)]
@@ -317,6 +323,10 @@ impl<'a> Shell<'a> {
                         return None;
                     }
 
+                    if let Some(cmd) = line.strip_prefix('!') {
+                        return Some((Command::Exec(cmd.to_string()), vec![]));
+                    }
+
                     let cmd = match shellwords::split(&line) {
                         Ok(cmd) => cmd,
                         Err(err) => {
@@ -490,8 +500,8 @@ pub fn run_once(rl: &mut Shell) -> Result<bool> {
     match line {
         Some((Command::Activity, args)) => cmd::<activity_cmd::Args>(rl, &args)?,
         Some((Command::Add, args)) => cmd::<add_cmd::Args>(rl, &args)?,
-        Some((Command::Autonoscope, args)) => autonoscope_cmd::run(rl, &args)?,
-        Some((Command::Autoscope, args)) => autoscope_cmd::run(rl, &args)?,
+        Some((Command::Autonoscope, args)) => cmd::<autonoscope_cmd::Args>(rl, &args)?,
+        Some((Command::Autoscope, args)) => cmd::<autoscope_cmd::Args>(rl, &args)?,
         Some((Command::Back, _)) => if rl.take_module().is_none() {
             return Ok(true);
         },
@@ -504,6 +514,7 @@ pub fn run_once(rl: &mut Shell) -> Result<bool> {
         },
         Some((Command::Noscope, args)) => noscope_cmd::run(rl, &args)?,
         Some((Command::Pkg, args)) => cmd::<pkg_cmd::ArgsInteractive>(rl, &args)?,
+        Some((Command::Rescope, args)) => cmd::<rescope_cmd::Args>(rl, &args)?,
         Some((Command::Run, args)) => cmd::<run_cmd::Args>(rl, &args)?,
         Some((Command::Scope, args)) => scope_cmd::run(rl, &args)?,
         Some((Command::Set, args)) => set_cmd::run(rl, &args)?,
@@ -518,6 +529,9 @@ pub fn run_once(rl: &mut Shell) -> Result<bool> {
         Some((Command::Exit, _)) => return Ok(true),
         Some((Command::Quit, _)) => return Ok(true),
         Some((Command::Interrupt, _)) => return Ok(true),
+        Some((Command::Exec(cmd), _)) => {
+            shell_exec(&cmd, rl.workspace())?;
+        },
         None => (),
     }
 
@@ -543,7 +557,7 @@ pub fn init<'a>(args: &Args, config: &'a Config, verbose_init: bool) -> Result<S
     let psl = PslReader::open_or_download(&cache_dir,
             |cb| worker::spawn_fn("Downloading public suffix list", cb, false))
         .context("Failed to download public suffix list")?;
-    let library = Library::new(verbose_init, &config)?;
+    let library = Library::new(verbose_init, config)?;
     let keyring = KeyRing::init()?;
 
     if verbose_init && library.list().is_empty() {
@@ -555,15 +569,35 @@ pub fn init<'a>(args: &Args, config: &'a Config, verbose_init: bool) -> Result<S
     if autoupdate.outdated() > 0 {
         term::warn(&format!("{} modules are outdated, run: \x1b[1mpkg update\x1b[0m", autoupdate.outdated()));
     }
-    autoupdate.check_background(&config, library.list());
+    autoupdate.check_background(config, library.list());
 
-    let mut rl = Shell::new(&config, db, blobs, psl, library, keyring);
+    let mut rl = Shell::new(config, db, blobs, psl, library, keyring);
 
     ttl::reap_expired(&mut rl)?;
 
     Ok(rl)
 }
 
+pub fn shell_exec(cmd: &str, workspace: &str) -> Result<()> {
+    use std::process::Command;
+
+    let sh = if cfg!(target_os = "windows") {
+        ("cmd", "/C")
+    } else {
+        ("sh", "-c")
+    };
+
+    Command::new(sh.0)
+            .arg(sh.1)
+            .arg(cmd)
+            .env("SN0INT_WORKSPACE", workspace)
+            .spawn()
+            .context("Failed to execute process")?
+            .wait()?;
+
+    Ok(())
+}
+
 pub fn run(args: &Args, config: &Config) -> Result<()> {
     print_banner();
 
