@@ -199,7 +199,7 @@ impl DatabaseEvent {
     }
 
     fn on_activity<T: SpinLogger>(rl: &mut Shell, spinner: &mut T, ratelimit: &mut Ratelimiter, object: &NewActivity, verbose: u64) {
-        Self::spinner_log_new_activity(spinner, &object, verbose);
+        Self::spinner_log_new_activity(spinner, object, verbose);
 
         // TODO: we don't want to copy the match arms everywhere
         let mut subject = format!("New activity: {:?}", object.topic);
@@ -330,7 +330,7 @@ impl DatabaseEvent {
 
         let result = match result {
             Ok(id) => {
-                Self::on_update(rl, spinner, ratelimit, family, &value, &update);
+                Self::on_update(rl, spinner, ratelimit, family, value, update);
                 Ok(DatabaseResponse::Updated(id))
             },
             Err(err) => {
@@ -437,7 +437,15 @@ impl RatelimitEvent {
     }
 }
 
-pub fn spawn(rl: &mut Shell, module: &Module, ratelimit: &mut Ratelimiter, args: Vec<(serde_json::Value, Option<String>, Vec<Blob>)>, params: &Params, proxy: Option<SocketAddr>, options: HashMap<String, String>) -> usize {
+pub fn spawn(rl: &mut Shell,
+             module: &Module,
+             ratelimit: &mut Ratelimiter,
+             args: Vec<(serde_json::Value, Option<String>, Vec<Blob>)>,
+             params: &Params,
+             proxy: Option<SocketAddr>,
+             user_agent: Option<String>,
+             options: HashMap<String, String>,
+) -> usize {
     // This function hangs if args is empty, so return early if that's the case
     if args.is_empty() {
         return 0;
@@ -445,7 +453,7 @@ pub fn spawn(rl: &mut Shell, module: &Module, ratelimit: &mut Ratelimiter, args:
 
     let verbose = params.verbose;
     let has_stdin = params.stdin;
-    let keyring = rl.keyring().request_keys(&module);
+    let keyring = rl.keyring().request_keys(module);
 
     let mut stack = StackedSpinners::new();
 
@@ -463,6 +471,7 @@ pub fn spawn(rl: &mut Shell, module: &Module, ratelimit: &mut Ratelimiter, args:
         let tx = tx.clone();
         let module = module.clone();
         let keyring = keyring.clone();
+        let user_agent = user_agent.clone();
         let options = options.clone();
         let signal_register = rl.signal_register().clone();
         pool.execute(move || {
@@ -476,7 +485,7 @@ pub fn spawn(rl: &mut Shell, module: &Module, ratelimit: &mut Ratelimiter, args:
             }
 
             tx.send(Event2::Start);
-            let event = match ipc::parent::run(module, &tx, arg, keyring, verbose, has_stdin, proxy, options, blobs) {
+            let event = match ipc::parent::run(module, &tx, arg, keyring, verbose, has_stdin, proxy, user_agent, options, blobs) {
                 Ok(exit) => exit,
                 Err(err) => ExitEvent::SetupFailed(err.to_string()),
             };
